function HydraNumPlot_s1


% general settings
mod = 1;
s1s = [10000, 15000, 20000, 25000]./10000;  % different max values of spore yield
v = 0.07;   						% default virulence
%b = 2.86 * 10^-5 * 10000;  					% default sensitivity
b=0;
e = 8.5;				% conversion efficiency 
d = 0.03;  				% background death rate of hosts
r = 0.8; 				% maximal growth rate of the algal resource (r_m in text)
fs0 = 0.0178;            		% size-specific foraging rate of uninfecteds
L = 1.4;				% length of animals
fs = fs0*L^2;

% loop through K - parameters
Kmin = 0.5;  % minimal carring capacity
Kmax = 3;  % maximum carrying capacity
Kint = 0.05;  % interval over which carrying capacity is varied

si = 0; % initilize counter
for s = 1:1:length(s1s)
si = si + 1; % advance loop counter through sigmas
s1 = s1s(si); % sigma to use
ki = 0; % initialize counters

for K = Kmin:Kint:Kmax
    ki= ki+1; % advance K counter
    Kp(ki) = K; % vector of K for plotting
    Sb(ki) = Sbnd(d,e,fs,r,K);

    % initialize ODE solver
    S0 = 10;  % inintial susceptible density, #/L
    Q0 = 0;	 % initial infected density, #/L
    Z0 = 5000/10000;  % initial spore density, #/L, with some scaling
    A0 = 1;	 % initial food density, mg C/L
    Y0 = [S0; Q0; Z0; A0];  % package initial values together

    options = odeset('RelTol', 1e-5, 'AbsTol', 1e-6); % some tolerance settings for the integrator
    Tt = []; Yt = [];  % initialize
    [Tt,Yt] = ode45('FeedingReduction_AllModels_ODE', [0,1000], Y0, options, s1, K, b, v, mod);  % simulate for initial values
    Y0n = Yt(end,:);  % get end value to intialize numerical solver.
    Yeq = FeedingReduction_AllModels_NUM(Y0n, s1, K, b, v, mod);  % numerical solution of interior equilibrium
    Snum(ki,si) = Yeq(1);  % value of S
    Inum(ki,si) = Yeq(2);  % value of I
    Nnum(ki,si) = Yeq(1) + Yeq(2);  % total host density

end % K loop
end % s1 loop


% make plot
plot(Kp,Nnum(:,1),'k-'); hold on;
plot(Kp,Nnum(:,2),'k--'); hold on;
plot(Kp,Nnum(:,3),'k-.'); hold on;
plot(Kp,Nnum(:,4),'k:'); hold on;
plot(Kp,Sb,'b-'); hold off