function PLOT_Figure4_Maps_14March2021

% DESCRIPTION: generates figure 4 of Penczykowski et al. 2021 American Naturalist
% updated 14 March 2021
% written by Spencer Hall, Indiana University, sprhall@iu.edu


% GENERAL FIGURE SETTINGS

hfig = figure(4);
clf(hfig)
set(hfig, 'Units', 'inches', 'Position', [15 0.5 5 6.5]);
lw = 1.25; % most line widths
lwR0 = 2.5; % line width for R0 = 1
xl = 1; xr = 2.75; % x-position of left column and right column, respectivley
yr1=4.75; yr2 = 2.75; % y-position of row 1 and row 2, respectively
lightyellow=[255,255,204]./255; lightgrey=[217,217,217]./255; % colors for filling
yl2 = 0.4; % distance of secondary (RHS) y-axis label, distance over




% PANEL A - K vs virulence, alpha > 0 

% load K-virulence - alpha > 0 - the values plotted on panel A
kv1=dlmread('Map_kv_1.txt'); % k-v map, assuming diff fhat - load data
k2v1=dlmread('Map_k2v_1.txt'); % values of v when Ai* = K/2 - load data


% make plot
subplot(3,2,1)
xmin = 0; xmax=3; ymin = 0; ymax = 0.15; % settings
c=0; % counter

% the fill-in are of the plot
for x = 1:1:length(kv1(:,1))-1      % Fill area of graph
    c = c+1;
    patch([kv1(x,1),kv1(x+1,1),kv1(x+1,1),kv1(x,1)],... % yellow part of plot
        [ymin,ymin,kv1(x+1,2),kv1(x,2)],'yellow',...
       'FaceColor', lightyellow, 'EdgeColor',lightyellow); hold on
    patch([kv1(x,1),kv1(x+1,1),kv1(1+1,1),kv1(1,1)],... % grey part of the plot
    [kv1(x,2),kv1(x+1),ymax,ymax],'yellow',...
    'FaceColor', lightgrey, 'EdgeColor',lightgrey); hold on
end 
    patch([KatR0,kv1(1,1),kv1(1+1,1),KatR0],...  % last part of fill
        [ymin,ymin,ymax,ymax],'yellow',...
        'FaceColor', lightgrey, 'EdgeColor',lightgrey); hold on

% the lines of the plot
plot(kv1(:,1),kv1(:,2),'k-', 'LineWidth', lw); hold on   % H-TC threshold
plot(k2v1(:,1),k2v1(:,2),'k--', 'LineWidth', lw); hold on   % Ai* - K/2 threshold
plot([K2atSb,K2atSb],[0,ymax],'k:','LineWidth', lw); hold on
plot([KatR0,KatR0],[0,ymax],'k-','LineWidth', lwR0); hold off   % R0 = 1 line
%plot([KatSb,KatSb],[0,ymax]); hold off   % R0 = 1 line

% the rest of the plot's details
axis([xmin, xmax, ymin, ymax]);
ylabel({'Virulence mortality,';'{\it{v}} (day^{-1})'},  'FontName', 'Arial', ...
    'FontSize', 10);
set(gca, 'Box', 'off', 'TickDir', 'out', 'TickLength', [0.04, 0.025], 'LineWidth', 1,...
   'Units', 'inches', 'Position', [xl, yr1, 1.5 1.5],'FontName', 'Arial',   'FontSize', 8);
text(xmax-0.1*(xmax-xmin), ymax-0.075*(ymax-ymin), 'a', 'FontName','Arial', 'FontSize', 11, 'FontWeight', 'bold');
rectangle('Position',[xmin,ymin,(xmax-xmin),(ymax-ymin)],'EdgeColor','k','LineWidth', 1 )
set(gca, 'YTickLabel', num2str(get(gca,'YTick')','%0.2f'));
set(gca, 'XTickLabel', []);
ylct=title('With {\itspores} mech.' ,'FontName','Arial', 'FontSize', 10,'FontWeight', 'bold' );
ylct.Position(2) = ylct.Position(2) + 0.005;
text(3*(xmax-xmin)/4, ymin+(ymax-ymin)/3, '{\itN}\uparrow', 'FontName','Arial', ... % N up
    'FontSize', 11, 'FontWeight', 'bold','HorizontalAlignment', 'center');
text(1*(xmax-xmin)/6, ymin+2*(ymax-ymin)/3, '{\itN}\downarrow', 'FontName','Arial', ... % N down
    'FontSize', 11, 'FontWeight', 'bold','HorizontalAlignment', 'center');
text(1*(xmax-xmin)/15, ymin+0.92*(ymax-ymin), '{\itR}_0=1', 'FontName','Arial', ... % R0 bel
    'FontSize', 8, 'HorizontalAlignment', 'left');
text(0.35*(xmax-xmin), ymin+0.94*(ymax-ymin), '{\itA_i}^*={\itK}/2', 'FontName','Arial', ... % R0 bel
    'FontSize', 8, 'HorizontalAlignment', 'left');
text(0.667*(xmax-xmin), ymin+0.925*(ymax-ymin), 'C-H', 'FontName','Arial', ... % R0 bel
    'FontSize', 8, 'HorizontalAlignment', 'left');




% PANEL B - K vs v, alpha = 0

% load K-v - b is 0.1 of default; calculated using other code
kv1b=dlmread('Map_kv_1b.txt'); % k-v map, assuming diff fhat - load in the data
k2v1b=dlmread('Map_k2v_1b.txt'); % values of v when Ai* = K/2 - load in the data

% make plot
subplot(3,2,2)

% the filled in areas of the plot
for x = 1:1:length(kv1(:,1))-1      % Fill area of graph
    c = c+1;
    patch([kv1b(x,1),kv1b(x+1,1),kv1b(x+1,1),kv1b(x,1)],...
        [ymin,ymin,kv1b(x+1,2),kv1b(x,2)],'yellow',...
       'FaceColor', lightyellow, 'EdgeColor',lightyellow); hold on
    patch([kv1b(x,1),kv1b(x+1,1),kv1b(1+1,1),kv1b(1,1)],...
    [kv1b(x,2),kv1b(x+1),ymax,ymax],'yellow',...
    'FaceColor', lightgrey, 'EdgeColor',lightgrey); hold on
end 
    patch([KatR0,kv1b(1,1),kv1b(1+1,1),KatR0],...  % last part of fill
        [ymin,ymin,ymax,ymax],'yellow',...
        'FaceColor', lightgrey, 'EdgeColor',lightgrey); hold on

% the lines on top of the filled in areas
plot(kv1b(:,1),kv1b(:,2),'k-', 'LineWidth', lw); hold on
plot(k2v1b(:,1),k2v1b(:,2),'k--', 'LineWidth', lw); hold on   % Ai* - K/2 threshold
plot([K2atSb,K2atSb],[0,ymax],'k:','LineWidth', lw); hold on
plot([KatR0,KatR0],[0,ymax],'k-','LineWidth', lwR0); hold off   % R0 = 1 line
%plot([KatSb,KatSb],[0,ymax]); hold off   % R0 = 1 line

% the rest of the plot
xmin = 0.0; xmax=3; ymin = 0; ymax = 0.15; 
axis([xmin, xmax, ymin, ymax]);
set(gca, 'Box', 'off', 'TickDir', 'out', 'TickLength', [0.04, 0.025], 'LineWidth', 1,...
   'Units', 'inches', 'Position', [xr,yr1, 1.5 1.5],'FontName', 'Arial',   'FontSize', 8);
text(xmax-0.1*(xmax-xmin), ymax-0.075*(ymax-ymin), 'b', 'FontName','Arial', 'FontSize', 11, 'FontWeight', 'bold');
rectangle('Position',[xmin,ymin,(xmax-xmin),(ymax-ymin)],'EdgeColor','k','LineWidth', 1 )
set(gca, 'XTickLabel', []); set(gca, 'YTickLabel', []);
yrct=title('Without {\itspores} mech.' ,'FontName','Arial', 'FontSize', 10,'FontWeight', 'bold' );
yrct.Position(2) = yrct.Position(2) + 0.005;
set(gca,'YAxisLocation', 'right');
text(3*(xmax-xmin)/4, ymin+(ymax-ymin)/3, '{\itN}\uparrow', 'FontName','Arial', ... % N up
    'FontSize', 11, 'FontWeight', 'bold','HorizontalAlignment', 'center');
text(1*(xmax-xmin)/3, ymin+2*(ymax-ymin)/3, '{\itN}\downarrow', 'FontName','Arial', ... % N down
    'FontSize', 11, 'FontWeight', 'bold','HorizontalAlignment', 'center');

ylabel('With {\itstatus} mech.',...
    'FontName', 'Arial',   'FontSize', 10, 'Rotation',270,'FontWeight', 'bold')
set(gca,'YAxisLocation', 'right');
ylabh = get(gca,'Ylabel');
set(ylabh, 'Position',get(ylabh,'Position') + [yl2 0 0])





% PANEL C - K vs alpha, higher virulence, f-hat_S > f-hat_I

% load K-alpha - high virulence (v = 0.07); load in the data
ka1=dlmread('Map_ka_1.txt'); % k-alpha map, assuming diff fhat
k2a1=dlmread('Map_k2a_1.txt'); % A* = K/2


% make plot
subplot(3,2,3)
xmin = 0.0; xmax=3; ymin = 0; ymax = 0.6; 

% the filled in areas of the graph
for x = 1:1:length(ka1(:,1))-1      % Fill area of graph
    c = c+1;
    patch([ka1(x,1),ka1(x,1),ka1(x+1,1),ka1(x+1,1)],...
        [ymax,ka1(x,2),ka1(x+1,2),ymax],'yellow',...
       'FaceColor', lightyellow, 'EdgeColor',lightyellow); hold on
    patch([ka1(x,1),ka1(x+1,1),ka1(x+1,1),ka1(x,1)],...
    [ymin,ymin,ka1(x+1,2),ka1(x,2)],'yellow',...
    'FaceColor', lightgrey, 'EdgeColor',lightgrey); hold on
end 
    patch([KatR0,ka1(1,1),ka1(1+1,1),KatR0],...  % last part of fill
        [ymin,ymin,ymax,ymax],'yellow',...
        'FaceColor', lightgrey, 'EdgeColor',lightgrey); hold on
    patch([ka1(end,1),xmax,xmax,ka1(end,1)],...  % last part of fill
        [ymin,ymin,ymax,ymax],'yellow',...
        'FaceColor', lightyellow, 'EdgeColor',lightyellow); hold on

% the lines on top of the filled in area
plot(ka1(:,1),ka1(:,2),'k-', 'LineWidth', lw); hold on
plot(k2a1(:,1),k2a1(:,2),'k--', 'LineWidth', lw); hold on % A* = K/2
plot([K2atSb,K2atSb],[0,ymax],'k:','LineWidth', lw); hold on
plot([KatR0,KatR0],[0,ymax],'k-','LineWidth', lwR0); hold off   % R0 = 1 line

% the rest of the plot
set(gca, 'Box', 'off', 'TickDir', 'out', 'TickLength', [0.04, 0.025], 'LineWidth', 1,...
   'Units', 'inches', 'Position', [xl, yr2, 1.5 1.5],'FontName', 'Arial',   'FontSize', 8);
axis([xmin, xmax, ymin, ymax]);
ylabel({'Sensitivity of foraging,';'{\it\alpha} (mm^3 spore^{-1} x 10^{-5})'},  'FontName', 'Arial', ...
    'FontSize', 10);
text(xmax-0.1*(xmax-xmin), ymax-0.075*(ymax-ymin), 'c', 'FontName','Arial', 'FontSize', 11, 'FontWeight', 'bold');
rectangle('Position',[xmin,ymin,(xmax-xmin),(ymax-ymin)],'EdgeColor','k','LineWidth', 1 )
set(gca, 'YTickLabel', num2str(get(gca,'YTick')','%0.1f'));
set(gca, 'XTickLabel', num2str(get(gca,'XTick')','%0.1f'));
set(gca, 'XTickLabel', []);
ylct2=title('\bfHigher virul. ({\itv} = 0.06)' ,'FontName','Arial', 'FontSize', 10 );
ylct2.Position(2) = ylct2.Position(2) + 0.01;
text(3*(xmax-xmin)/4, ymin+(ymax-ymin)/3, '{\itN}\uparrow', 'FontName','Arial', ... % N up
    'FontSize', 11, 'FontWeight', 'bold','HorizontalAlignment', 'center');
text(1*(xmax-xmin)/7, ymin+2*(ymax-ymin)/3, '{\itN}\downarrow', 'FontName','Arial', ... % N down
    'FontSize', 11, 'FontWeight', 'bold','HorizontalAlignment', 'center');






% PANEL D - K vs alpha, low virulence

% load K-alpha - low virulence (v = 0.03); data calculated elswhere
ka1b=dlmread('Map_ka_1b.txt'); % k-alpha map, assuming diff fhat
k2a1b=dlmread('Map_k2a_1b.txt'); % k-alpha map, assuming diff fhat

% make plot
subplot(3,2,4)
xmin = 0; xmax=3; ymin = 0; ymax = 0.6; 

% filled in region
for x = 1:1:length(ka1b(:,1))-1      % Fill area of graph
    c = c+1;
    patch([ka1b(x,1),ka1b(x,1),ka1b(x+1,1),ka1b(x+1,1)],...
        [ymax,ka1b(x,2),ka1b(x+1,2),ymax],'yellow',...
       'FaceColor', lightyellow, 'EdgeColor',lightyellow); hold on
    patch([ka1b(x,1),ka1b(x+1,1),ka1b(x+1,1),ka1b(x,1)],...
    [ymin,ymin,ka1b(x+1,2),ka1b(x,2)],'yellow',...
    'FaceColor', lightgrey, 'EdgeColor',lightgrey); hold on
end 
    patch([KatR0,ka1b(1,1),ka1b(1+1,1),KatR0],...  % last part of fill
        [ymin,ymin,ymax,ymax],'yellow',...
        'FaceColor', lightgrey, 'EdgeColor',lightgrey); hold on
    patch([ka1b(end,1),xmax,xmax,ka1b(end,1)],...  % last part of fill
        [ymin,ymin,ymax,ymax],'yellow',...
        'FaceColor', lightyellow, 'EdgeColor',lightyellow); hold on

% lines on top of filled in region
plot(ka1b(:,1),ka1b(:,2),'k-', 'LineWidth', lw); hold on
plot([ka1b(1,1),ka1b(1,1)],[ka1b(1,2),ymax],'k-', 'LineWidth', lw); hold on
plot(k2a1b(:,1),k2a1b(:,2),'k--', 'LineWidth', lw); hold on % A* = K/2
plot([K2atSb,K2atSb],[0,ymax],'k:','LineWidth', lw); hold on
plot([KatR0,KatR0],[0,ymax],'k-','LineWidth', lwR0); hold off   % R0 = 1 line

% rest of plot
axis([xmin, xmax, ymin, ymax]);
set(gca, 'Box', 'off', 'TickDir', 'out', 'TickLength', [0.04, 0.025], 'LineWidth', 1,...
   'Units', 'inches', 'Position', [xr, yr2, 1.5 1.5],'FontName', 'Arial',   'FontSize', 8);
text(xmax-0.1*(xmax-xmin), ymax-0.075*(ymax-ymin), 'd', 'FontName','Arial', 'FontSize', 11, 'FontWeight', 'bold');
rectangle('Position',[xmin,ymin,(xmax-xmin),(ymax-ymin)],'EdgeColor','k','LineWidth', 1 )
set(gca, 'XTickLabel', []); set(gca, 'YTickLabel', []);
yrct2=title('\bfLower virul. ({\itv} = 0.03)' ,'FontName','Arial', 'FontSize', 10 );
yrct2.Position(2) = yrct2.Position(2) + 0.01;

text(2*(xmax-xmin)/3, ymin+(ymax-ymin)/3, '{\itN}\uparrow', 'FontName','Arial', ... % N up
    'FontSize', 11, 'FontWeight', 'bold','HorizontalAlignment', 'center');
text(1*(xmax-xmin)/8, ymin+2*(ymax-ymin)/3, '{\itN}\downarrow', 'FontName','Arial', ... % N down
    'FontSize', 11, 'FontWeight', 'bold','HorizontalAlignment', 'center');

ylabel('With {\itstatus} mech.','FontName', 'Arial', 'FontSize', 10, ...
    'Rotation',270,'FontWeight', 'bold')
set(gca,'YAxisLocation', 'right');
ylabh = get(gca,'Ylabel');
set(ylabh, 'Position',get(ylabh,'Position') + [yl2 0 0])





% PANEL E - K vs alpha, higher virulence

% load K-alpha - high virulence (v = 0.07);
ka2=dlmread('Map_ka_2.txt'); % k-alpha map, assuming same fhat
k2a2=dlmread('Map_k2a_2.txt'); % k-alpha map, assuming same fhat

% make plot
subplot(3,2,5)
xmin = 0.0; xmax=3; ymin = 0; ymax = 0.6; 

% filled in areas
for x = 1:1:length(ka2(:,1))-1      % Fill area of graph
    c = c+1;
    patch([ka2(x,1),ka2(x,1),ka2(x+1,1),ka2(x+1,1)],...
        [ymax,ka2(x,2),ka2(x+1,2),ymax],'yellow',...
       'FaceColor', lightyellow, 'EdgeColor',lightyellow); hold on
    patch([ka2(x,1),ka2(x+1,1),ka2(x+1,1),ka2(x,1)],...
    [ymin,ymin,ka2(x+1,2),ka2(x,2)],'yellow',...
    'FaceColor', lightgrey, 'EdgeColor',lightgrey); hold on
end 
    patch([KatR0,ka2(1,1),ka2(1+1,1),KatR0],...  % last part of fill
        [ymin,ymin,ymax,ymax],'yellow',...
        'FaceColor', lightgrey, 'EdgeColor',lightgrey); hold on
    patch([ka2(end,1),xmax,xmax,ka2(end,1)],...  % last part of fill
        [ymin,ymin,ymax,ymax],'yellow',...
        'FaceColor', lightyellow, 'EdgeColor',lightyellow); hold on

% lines on top of filled in areas
plot(ka2(:,1),ka2(:,2),'k-','LineWidth', lw); hold on
plot(k2a2(:,1),k2a2(:,2),'k--', 'LineWidth', lw); hold on % A* = K/2
plot([K2atSb,K2atSb],[0,ymax],'k:','LineWidth', lw); hold on
plot([KatR0,KatR0],[0,ymax],'k-','LineWidth', lwR0); hold off   % R0 = 1 line

% rest of plot
set(gca, 'Box', 'off', 'TickDir', 'out', 'TickLength', [0.04, 0.025], 'LineWidth', 1,...
   'Units', 'inches', 'Position', [xl, 1, 1.5 1.5],'FontName', 'Arial',   'FontSize', 8);
axis([xmin, xmax, ymin, ymax]);
ylabel({'Sensitivity of foraging,';'{\it\alpha} (mm^3 spore^{-1} x 10^{-5})'},  'FontName', 'Arial', ...
    'FontSize', 10);
text(xmax-0.1*(xmax-xmin), ymax-0.075*(ymax-ymin), 'e', 'FontName','Arial', 'FontSize', 11, 'FontWeight', 'bold');
rectangle('Position',[xmin,ymin,(xmax-xmin),(ymax-ymin)],'EdgeColor','k','LineWidth', 1 )
set(gca, 'YTickLabel', num2str(get(gca,'YTick')','%0.1f'));
set(gca, 'XTickLabel', num2str(get(gca,'XTick')','%0.0f'));
xalb=xlabel('Carrying capacity, {\itK} (mg/L)', ...
    'FontName', 'Arial', 'FontSize', 10);
xalb.Position(1) = xalb.Position(1) + 1.85;

text(3*(xmax-xmin)/4, ymin+3*(ymax-ymin)/4, '{\itN}\uparrow', 'FontName','Arial', ... % N up
    'FontSize', 11, 'FontWeight', 'bold','HorizontalAlignment', 'center');
text(1*(xmax-xmin)/3, ymin+1*(ymax-ymin)/4, '{\itN}\downarrow', 'FontName','Arial', ... % N down
    'FontSize', 11, 'FontWeight', 'bold','HorizontalAlignment', 'center');




% PANEL F - K vs alpha, low virulence

% load K-alpha - low virulence (v = 0.03); load in data
ka2b=dlmread('Map_ka_2b.txt'); % k-alpha map, assuming same fhat
k2a2b=dlmread('Map_k2a_2b.txt'); % k-alpha map, assuming same fhat

% make plot
subplot(3,2,6)
xmin = 0.0; xmax=3; ymin = 0; ymax = 0.6; 

% filled in areas
for x = 1:1:length(ka2b(:,1))-1      % Fill area of graph
    c = c+1;
    patch([ka2b(x,1),ka2b(x,1),ka2b(x+1,1),ka2b(x+1,1)],...
        [ymax,ka2b(x,2),ka2b(x+1,2),ymax],'yellow',...
       'FaceColor', lightyellow, 'EdgeColor',lightyellow); hold on
    patch([ka2b(x,1),ka2b(x+1,1),ka2b(x+1,1),ka2b(x,1)],...
    [ymin,ymin,ka2b(x+1,2),ka2b(x,2)],'yellow',...
    'FaceColor', lightgrey, 'EdgeColor',lightgrey); hold on
end 
    patch([KatR0,ka2b(1,1),ka2b(1+1,1),KatR0],...  % last part of fill
        [ymin,ymin,ymax,ymax],'yellow',...
        'FaceColor', lightgrey, 'EdgeColor',lightgrey); hold on
    patch([ka2b(end,1),xmax,xmax,ka2b(end,1)],...  % last part of fill
        [ymin,ymin,ymax,ymax],'yellow',...
        'FaceColor', lightyellow, 'EdgeColor',lightyellow); hold on

% lines on top of filled in area
plot(ka2b(:,1),ka2b(:,2),'k-','LineWidth', lw); hold on
plot(k2a2b(:,1),k2a2b(:,2),'k--', 'LineWidth', lw); hold on % A* = K/2
plot([K2atSb,K2atSb],[0,ymax],'k:','LineWidth', lw); hold on
plot([KatR0,KatR0],[0,ymax],'k-','LineWidth', lwR0); hold off   % R0 = 1 line

% rest of plot
axis([xmin, xmax, ymin, ymax]);
set(gca, 'Box', 'off', 'TickDir', 'out', 'TickLength', [0.04, 0.025], 'LineWidth', 1,...
   'Units', 'inches', 'Position', [xr, 1, 1.5 1.5],'FontName', 'Arial',   'FontSize', 8);
text(xmax-0.1*(xmax-xmin), ymax-0.075*(ymax-ymin), 'f', 'FontName','Arial', 'FontSize', 11, 'FontWeight', 'bold');
rectangle('Position',[xmin,ymin,(xmax-xmin),(ymax-ymin)],'EdgeColor','k','LineWidth', 1 )
set(gca, 'YTickLabel', []);
set(gca, 'XTickLabel', num2str(get(gca,'XTick')','%0.0f'));

text(3*(xmax-xmin)/4, ymin+3*(ymax-ymin)/4, '{\itN}\uparrow', 'FontName','Arial', ... % N up
    'FontSize', 11, 'FontWeight', 'bold','HorizontalAlignment', 'center');
text(1*(xmax-xmin)/3, ymin+1*(ymax-ymin)/4, '{\itN}\downarrow', 'FontName','Arial', ... % N down
    'FontSize', 11, 'FontWeight', 'bold','HorizontalAlignment', 'center');

ylabel('Without {\itstatus} mech.',...
    'FontName', 'Arial',   'FontSize', 10, 'Rotation',270,'FontWeight', 'bold')
set(gca,'YAxisLocation', 'right');
ylabh = get(gca,'Ylabel');
set(ylabh, 'Position',get(ylabh,'Position') + [yl2 0 0])


set(gcf, 'Color', 'w');




print(hfig, 'Figure 4.eps', '-depsc2');
